==> lonny_proc-0.1.5.tar.gz: lonny_proc-0.1.5/lonny_proc/cli.py <==
from .manager import Manager, RestartPolicy
from .logger import logger
from logging import StreamHandler, INFO
from argparse import ArgumentParser
from importlib import import_module
from time import sleep 
from signal import signal, SIGINT, SIGTERM, SIG_IGN
import sys

MONITOR_CYCLE = 0.5

logger.addHandler(StreamHandler())
logger.setLevel(INFO)

parser = ArgumentParser()
parser.add_argument("targets", nargs = "+", type = str)
parser.add_argument("-p", "--policy", 
    type = str, 
    choices = list(x.name for x in RestartPolicy),
    default = RestartPolicy.never.name
)

class Handler:
    def __init__(self):
        self._terminate = False

    def __call__(self, _sig, _frame):
        self._terminate = True

    @property
    def terminate(self):
        return self._terminate

def _build_targets(args):
    targets = list()
    for target in args.targets:
        split = f"{target}:1".split(":")
        # don't preload the app! Wrap the code in a lambda so the import
        # is loaded by each child separately,
        fn = lambda: import_module(split[0]).__getattribute__(split[1])()
        for _ in range(int(split[2])):
            targets.append(fn)
    return targets

def run():
    sys.path.insert(0, "")
    hdlr = Handler()
    args = parser.parse_args()
    targets = _build_targets(args)
    # Child processes inherit the handlers of their parents. We want child
    # processes to ignore SIGINTs so we must set the parent handler as such
    # before the children are spawned.
    signal(SIGINT, SIG_IGN)
    with Manager(* targets, restart_policy = RestartPolicy[args.policy]) as mgr:
        # Now that the children are spawned, we can set the parent handlers to
        # whatever we want.
        signal(SIGINT, hdlr)
        signal(SIGTERM, hdlr)
        while not hdlr.terminate:
            sleep(MONITOR_CYCLE)
            mgr.monitor()

==> lonny_proc-0.1.6.tar.gz: lonny_proc-0.1.6/lonny_proc/cli.py <==
from .manager import Manager, RestartPolicy
from .logger import logger
from logging import StreamHandler, INFO
from argparse import ArgumentParser
from importlib import import_module
from time import sleep 
from signal import signal, SIGINT, SIGTERM, SIG_IGN
import sys

MONITOR_CYCLE = 0.5

logger.addHandler(StreamHandler())
logger.setLevel(INFO)

parser = ArgumentParser()
parser.add_argument("target")
parser.add_argument("-p", "--preload", action="store_true")
parser.add_argument("-r", "--restart_policy", 
    type = str, 
    choices = list(x.name for x in RestartPolicy),
    default = RestartPolicy.never.name
)

class Handler:
    def __init__(self):
        self._terminate = False

    def __call__(self, _sig, _frame):
        self._terminate = True

    @property
    def terminate(self):
        return self._terminate

def _build_targets(args):
    module, fn, instances, *_ = f"{args.target}:1".split(":")
    if args.preload:
        import_module(module)
    target = lambda: import_module(module).__getattribute__(fn)()
    return [ target for _ in range(int(instances))]

def run():
    sys.path.insert(0, "")
    hdlr = Handler()
    args = parser.parse_args()
    targets = _build_targets(args)
    # Child processes inherit the handlers of their parents. We want child
    # processes to ignore SIGINTs so we must set the parent handler as such
    # before the children are spawned.
    signal(SIGINT, SIG_IGN)
    with Manager(* targets, restart_policy = RestartPolicy[args.restart_policy]) as mgr:
        # Now that the children are spawned, we can set the parent handlers to
        # whatever we want.
        signal(SIGINT, hdlr)
        signal(SIGTERM, hdlr)
        while not hdlr.terminate:
            sleep(MONITOR_CYCLE)
            mgr.monitor()
